@@ -293,6 +293,12 @@ class Gene:
             res = self.mutations[pos, op][1]
         return res if res != "-" or not default else f"{pos + 1}.{op}"
 
+    def get_allele(self, name):
+        for an, a in self.alleles.items():
+            if name in a.minors:
+                return (a, a.minors[name])
+        return None
+
     def get_refseq(self, *args, from_atg=False) -> str:
         """:returns: `True` if a mutation is functional."""
         assert 1 <= len(args) <= 2
@@ -536,6 +542,8 @@ class Gene:
         self.yml_mutations = yml["alleles"]
         self.random_mutations = set()
         for pos, op, *info in yml["alleles"].get("random", []):
+            if isinstance(pos, str) and pos == "ignored":
+                continue
             for m in process_mutation(pos, op, info):
                 self.random_mutations.add(m)
         self.mutation_groups = {}
@@ -781,6 +789,7 @@ class Gene:
             del self.alleles[f]
             self.alleles.update({a.name: a for a in add.values()})
 
+        self.removed = set()
         for an, a in self.alleles.items():
             # Clean up minor alleles (as many might be identical after a fusion).
             # Put a reference to the cleaned-up alleles in `alt_name` field.
@@ -792,6 +801,7 @@ class Gene:
                 if len(sa) > 1:
                     for s in sa:
                         if s != min(sa) and "#" not in s:
+                            self.removed.add(s)
                             log.debug(
                                 f"Removing {self.name}*{s} as it is the same as"
                                 f" {min(sa)}"
