@@ -385,13 +385,14 @@ class Sample:
                         self._indel_sites_eqs[np, no] = (pos, op)
                 continue
 
+            exact_match_for_shiftable = True
             valn = VariantAlignment(  # type: ignore
                 v,
                 sam,
                 mapping_quality_threshold=self.profile.min_mapq,
                 base_quality_threshold=self.profile.min_quality,
                 # needed to account for indel and database errors
-                exact_match_for_shiftable=True,
+                exact_match_for_shiftable=exact_match_for_shiftable,
             )
 
             phased = valn.phase()
